# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .field_map import FieldMap
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DirectNamedFieldMap(FieldMap):
    """
    A named field map.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DirectNamedFieldMap object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.DirectNamedFieldMap.model_type` attribute
        of this class is ``DIRECT_NAMED_FIELD_MAP`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this DirectNamedFieldMap.
            Allowed values for this property are: "DIRECT_NAMED_FIELD_MAP", "COMPOSITE_FIELD_MAP", "DIRECT_FIELD_MAP", "RULE_BASED_FIELD_MAP"
        :type model_type: str

        :param description:
            The value to assign to the description property of this DirectNamedFieldMap.
        :type description: str

        :param key:
            The value to assign to the key property of this DirectNamedFieldMap.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this DirectNamedFieldMap.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this DirectNamedFieldMap.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param config_values:
            The value to assign to the config_values property of this DirectNamedFieldMap.
        :type config_values: oci.data_integration.models.ConfigValues

        :param source_typed_object:
            The value to assign to the source_typed_object property of this DirectNamedFieldMap.
        :type source_typed_object: str

        :param target_typed_object:
            The value to assign to the target_typed_object property of this DirectNamedFieldMap.
        :type target_typed_object: str

        :param source_field_name:
            The value to assign to the source_field_name property of this DirectNamedFieldMap.
        :type source_field_name: str

        :param target_field_name:
            The value to assign to the target_field_name property of this DirectNamedFieldMap.
        :type target_field_name: str

        :param object_status:
            The value to assign to the object_status property of this DirectNamedFieldMap.
        :type object_status: int

        """
        self.swagger_types = {
            'model_type': 'str',
            'description': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'config_values': 'ConfigValues',
            'source_typed_object': 'str',
            'target_typed_object': 'str',
            'source_field_name': 'str',
            'target_field_name': 'str',
            'object_status': 'int'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'description': 'description',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'config_values': 'configValues',
            'source_typed_object': 'sourceTypedObject',
            'target_typed_object': 'targetTypedObject',
            'source_field_name': 'sourceFieldName',
            'target_field_name': 'targetFieldName',
            'object_status': 'objectStatus'
        }

        self._model_type = None
        self._description = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._config_values = None
        self._source_typed_object = None
        self._target_typed_object = None
        self._source_field_name = None
        self._target_field_name = None
        self._object_status = None
        self._model_type = 'DIRECT_NAMED_FIELD_MAP'

    @property
    def key(self):
        """
        Gets the key of this DirectNamedFieldMap.
        The object key.


        :return: The key of this DirectNamedFieldMap.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this DirectNamedFieldMap.
        The object key.


        :param key: The key of this DirectNamedFieldMap.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this DirectNamedFieldMap.
        The object's model version.


        :return: The model_version of this DirectNamedFieldMap.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this DirectNamedFieldMap.
        The object's model version.


        :param model_version: The model_version of this DirectNamedFieldMap.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this DirectNamedFieldMap.

        :return: The parent_ref of this DirectNamedFieldMap.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this DirectNamedFieldMap.

        :param parent_ref: The parent_ref of this DirectNamedFieldMap.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def config_values(self):
        """
        Gets the config_values of this DirectNamedFieldMap.

        :return: The config_values of this DirectNamedFieldMap.
        :rtype: oci.data_integration.models.ConfigValues
        """
        return self._config_values

    @config_values.setter
    def config_values(self, config_values):
        """
        Sets the config_values of this DirectNamedFieldMap.

        :param config_values: The config_values of this DirectNamedFieldMap.
        :type: oci.data_integration.models.ConfigValues
        """
        self._config_values = config_values

    @property
    def source_typed_object(self):
        """
        Gets the source_typed_object of this DirectNamedFieldMap.
        Reference to a typed object.


        :return: The source_typed_object of this DirectNamedFieldMap.
        :rtype: str
        """
        return self._source_typed_object

    @source_typed_object.setter
    def source_typed_object(self, source_typed_object):
        """
        Sets the source_typed_object of this DirectNamedFieldMap.
        Reference to a typed object.


        :param source_typed_object: The source_typed_object of this DirectNamedFieldMap.
        :type: str
        """
        self._source_typed_object = source_typed_object

    @property
    def target_typed_object(self):
        """
        Gets the target_typed_object of this DirectNamedFieldMap.
        Reference to a typed object


        :return: The target_typed_object of this DirectNamedFieldMap.
        :rtype: str
        """
        return self._target_typed_object

    @target_typed_object.setter
    def target_typed_object(self, target_typed_object):
        """
        Sets the target_typed_object of this DirectNamedFieldMap.
        Reference to a typed object


        :param target_typed_object: The target_typed_object of this DirectNamedFieldMap.
        :type: str
        """
        self._target_typed_object = target_typed_object

    @property
    def source_field_name(self):
        """
        Gets the source_field_name of this DirectNamedFieldMap.
        The source field name.


        :return: The source_field_name of this DirectNamedFieldMap.
        :rtype: str
        """
        return self._source_field_name

    @source_field_name.setter
    def source_field_name(self, source_field_name):
        """
        Sets the source_field_name of this DirectNamedFieldMap.
        The source field name.


        :param source_field_name: The source_field_name of this DirectNamedFieldMap.
        :type: str
        """
        self._source_field_name = source_field_name

    @property
    def target_field_name(self):
        """
        Gets the target_field_name of this DirectNamedFieldMap.
        The target field name.


        :return: The target_field_name of this DirectNamedFieldMap.
        :rtype: str
        """
        return self._target_field_name

    @target_field_name.setter
    def target_field_name(self, target_field_name):
        """
        Sets the target_field_name of this DirectNamedFieldMap.
        The target field name.


        :param target_field_name: The target_field_name of this DirectNamedFieldMap.
        :type: str
        """
        self._target_field_name = target_field_name

    @property
    def object_status(self):
        """
        Gets the object_status of this DirectNamedFieldMap.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this DirectNamedFieldMap.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this DirectNamedFieldMap.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this DirectNamedFieldMap.
        :type: int
        """
        self._object_status = object_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from cryptography.hazmat.primitives.ciphers import algorithms, modes

from enum import Enum


class Algorithm(Enum):
    """
    Represents an Algorithm that can be used to encrypt and decrypt payloads.
    """

    AES_256_GCM_IV12_TAG16 = (
        0,  # OCI SDK algo ID
        algorithms.AES,
        modes.GCM,
        32,  # key length
        12,  # initialization vector (IV) length, 96 bits is recommended, see section 5.2.1.1: https://nvlpubs.nist.gov/nistpubs/Legacy/SP/nistspecialpublication800-38d.pdf
        16,  # authentication tag length
        None,  # padding
        16,  # block size in bytes
    )

    def __init__(
        self,
        id,
        algorithm,
        mode,
        key_len,
        iv_len,
        tag_len=None,
        padding=None,
        block_size=None,
    ):
        """
        :param bytes id: (required)
            Identifier for this algorithm used in serialization

        :param cryptography.hazmat.primitives.ciphers.CipherAlgorithm algorithm: (required)
            Encryption algorithm to use.

        :param cryptography.hazmat.primitives.ciphers.modes.Mode mode: (required)
            Mode to use.

        :param int key_len: (required)
            Length of the key (in bytes).

        :param int iv_len: (required)
            Length of the initialization vector (in bytes).

        :param int tag_len: (optional)
            Length of the authentication tag (in bytes), if applicable.

        :param cryptography.hazmat.primitives.padding padding: (optional)
            Padding to use.

        :param int block_size: (optional)
            Size of each block.
        """
        self.id = id
        self.algorithm = algorithm
        self.mode = mode
        self.key_len = key_len
        self.iv_len = iv_len
        self.tag_len = tag_len
        self.padding = padding
        self.block_size = block_size



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ScheduleReportSummary(object):
    """
    Schedule report in list request.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ScheduleReportSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ScheduleReportSummary.
        :type id: str

        :param saved_schedule_report:
            The value to assign to the saved_schedule_report property of this ScheduleReportSummary.
        :type saved_schedule_report: oci.usage_api.models.SavedScheduleReport

        """
        self.swagger_types = {
            'id': 'str',
            'saved_schedule_report': 'SavedScheduleReport'
        }

        self.attribute_map = {
            'id': 'id',
            'saved_schedule_report': 'savedScheduleReport'
        }

        self._id = None
        self._saved_schedule_report = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ScheduleReportSummary.
        The Schedule report OCID.


        :return: The id of this ScheduleReportSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ScheduleReportSummary.
        The Schedule report OCID.


        :param id: The id of this ScheduleReportSummary.
        :type: str
        """
        self._id = id

    @property
    def saved_schedule_report(self):
        """
        Gets the saved_schedule_report of this ScheduleReportSummary.

        :return: The saved_schedule_report of this ScheduleReportSummary.
        :rtype: oci.usage_api.models.SavedScheduleReport
        """
        return self._saved_schedule_report

    @saved_schedule_report.setter
    def saved_schedule_report(self, saved_schedule_report):
        """
        Sets the saved_schedule_report of this ScheduleReportSummary.

        :param saved_schedule_report: The saved_schedule_report of this ScheduleReportSummary.
        :type: oci.usage_api.models.SavedScheduleReport
        """
        self._saved_schedule_report = saved_schedule_report

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AuthDetails(object):
    """
    Authentication type to be used for Generic REST invocation.
    """

    #: A constant which can be used with the model_type property of a AuthDetails.
    #: This constant has a value of "NO_AUTH_DETAILS"
    MODEL_TYPE_NO_AUTH_DETAILS = "NO_AUTH_DETAILS"

    #: A constant which can be used with the model_type property of a AuthDetails.
    #: This constant has a value of "RESOURCE_PRINCIPAL_AUTH_DETAILS"
    MODEL_TYPE_RESOURCE_PRINCIPAL_AUTH_DETAILS = "RESOURCE_PRINCIPAL_AUTH_DETAILS"

    def __init__(self, **kwargs):
        """
        Initializes a new AuthDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this AuthDetails.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this AuthDetails.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this AuthDetails.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param model_type:
            The value to assign to the model_type property of this AuthDetails.
            Allowed values for this property are: "NO_AUTH_DETAILS", "RESOURCE_PRINCIPAL_AUTH_DETAILS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        """
        self.swagger_types = {
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'model_type': 'str'
        }

        self.attribute_map = {
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'model_type': 'modelType'
        }

        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._model_type = None

    @property
    def key(self):
        """
        Gets the key of this AuthDetails.
        Generated key that can be used in API calls to identify data flow. On scenarios where reference to the data flow is needed, a value can be passed in create.


        :return: The key of this AuthDetails.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this AuthDetails.
        Generated key that can be used in API calls to identify data flow. On scenarios where reference to the data flow is needed, a value can be passed in create.


        :param key: The key of this AuthDetails.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this AuthDetails.
        The model version of an object.


        :return: The model_version of this AuthDetails.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this AuthDetails.
        The model version of an object.


        :param model_version: The model_version of this AuthDetails.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this AuthDetails.

        :return: The parent_ref of this AuthDetails.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this AuthDetails.

        :param parent_ref: The parent_ref of this AuthDetails.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def model_type(self):
        """
        Gets the model_type of this AuthDetails.
        The authentication mode to be used for Generic REST invocation.

        Allowed values for this property are: "NO_AUTH_DETAILS", "RESOURCE_PRINCIPAL_AUTH_DETAILS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The model_type of this AuthDetails.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this AuthDetails.
        The authentication mode to be used for Generic REST invocation.


        :param model_type: The model_type of this AuthDetails.
        :type: str
        """
        allowed_values = ["NO_AUTH_DETAILS", "RESOURCE_PRINCIPAL_AUTH_DETAILS"]
        if not value_allowed_none_or_none_sentinel(model_type, allowed_values):
            model_type = 'UNKNOWN_ENUM_VALUE'
        self._model_type = model_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseUpgradeHistoryEntry(object):
    """
    The Database service supports the upgrade history of databases.

    To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized, talk to an administrator. If you are an administrator who needs to write policies to give users access, see `Getting Started with Policies`__.

    For information about access control and compartments, see
    `Overview of the Identity Service`__.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.

    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/overview.htm
    """

    #: A constant which can be used with the action property of a DatabaseUpgradeHistoryEntry.
    #: This constant has a value of "PRECHECK"
    ACTION_PRECHECK = "PRECHECK"

    #: A constant which can be used with the action property of a DatabaseUpgradeHistoryEntry.
    #: This constant has a value of "UPGRADE"
    ACTION_UPGRADE = "UPGRADE"

    #: A constant which can be used with the action property of a DatabaseUpgradeHistoryEntry.
    #: This constant has a value of "ROLLBACK"
    ACTION_ROLLBACK = "ROLLBACK"

    #: A constant which can be used with the source property of a DatabaseUpgradeHistoryEntry.
    #: This constant has a value of "DB_HOME"
    SOURCE_DB_HOME = "DB_HOME"

    #: A constant which can be used with the source property of a DatabaseUpgradeHistoryEntry.
    #: This constant has a value of "DB_VERSION"
    SOURCE_DB_VERSION = "DB_VERSION"

    #: A constant which can be used with the source property of a DatabaseUpgradeHistoryEntry.
    #: This constant has a value of "DB_SOFTWARE_IMAGE"
    SOURCE_DB_SOFTWARE_IMAGE = "DB_SOFTWARE_IMAGE"

    #: A constant which can be used with the lifecycle_state property of a DatabaseUpgradeHistoryEntry.
    #: This constant has a value of "SUCCEEDED"
    LIFECYCLE_STATE_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the lifecycle_state property of a DatabaseUpgradeHistoryEntry.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a DatabaseUpgradeHistoryEntry.
    #: This constant has a value of "IN_PROGRESS"
    LIFECYCLE_STATE_IN_PROGRESS = "IN_PROGRESS"

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseUpgradeHistoryEntry object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this DatabaseUpgradeHistoryEntry.
        :type id: str

        :param action:
            The value to assign to the action property of this DatabaseUpgradeHistoryEntry.
            Allowed values for this property are: "PRECHECK", "UPGRADE", "ROLLBACK", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type action: str

        :param source:
            The value to assign to the source property of this DatabaseUpgradeHistoryEntry.
            Allowed values for this property are: "DB_HOME", "DB_VERSION", "DB_SOFTWARE_IMAGE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type source: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DatabaseUpgradeHistoryEntry.
            Allowed values for this property are: "SUCCEEDED", "FAILED", "IN_PROGRESS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this DatabaseUpgradeHistoryEntry.
        :type lifecycle_details: str

        :param target_db_version:
            The value to assign to the target_db_version property of this DatabaseUpgradeHistoryEntry.
        :type target_db_version: str

        :param target_database_software_image_id:
            The value to assign to the target_database_software_image_id property of this DatabaseUpgradeHistoryEntry.
        :type target_database_software_image_id: str

        :param target_db_home_id:
            The value to assign to the target_db_home_id property of this DatabaseUpgradeHistoryEntry.
        :type target_db_home_id: str

        :param source_db_home_id:
            The value to assign to the source_db_home_id property of this DatabaseUpgradeHistoryEntry.
        :type source_db_home_id: str

        :param time_started:
            The value to assign to the time_started property of this DatabaseUpgradeHistoryEntry.
        :type time_started: datetime

        :param time_ended:
            The value to assign to the time_ended property of this DatabaseUpgradeHistoryEntry.
        :type time_ended: datetime

        :param options:
            The value to assign to the options property of this DatabaseUpgradeHistoryEntry.
        :type options: str

        """
        self.swagger_types = {
            'id': 'str',
            'action': 'str',
            'source': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'target_db_version': 'str',
            'target_database_software_image_id': 'str',
            'target_db_home_id': 'str',
            'source_db_home_id': 'str',
            'time_started': 'datetime',
            'time_ended': 'datetime',
            'options': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'action': 'action',
            'source': 'source',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'target_db_version': 'targetDBVersion',
            'target_database_software_image_id': 'targetDatabaseSoftwareImageId',
            'target_db_home_id': 'targetDbHomeId',
            'source_db_home_id': 'sourceDbHomeId',
            'time_started': 'timeStarted',
            'time_ended': 'timeEnded',
            'options': 'options'
        }

        self._id = None
        self._action = None
        self._source = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._target_db_version = None
        self._target_database_software_image_id = None
        self._target_db_home_id = None
        self._source_db_home_id = None
        self._time_started = None
        self._time_ended = None
        self._options = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DatabaseUpgradeHistoryEntry.
        The `OCID`__ of the database upgrade history.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this DatabaseUpgradeHistoryEntry.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DatabaseUpgradeHistoryEntry.
        The `OCID`__ of the database upgrade history.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this DatabaseUpgradeHistoryEntry.
        :type: str
        """
        self._id = id

    @property
    def action(self):
        """
        **[Required]** Gets the action of this DatabaseUpgradeHistoryEntry.
        The database upgrade action.

        Allowed values for this property are: "PRECHECK", "UPGRADE", "ROLLBACK", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The action of this DatabaseUpgradeHistoryEntry.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this DatabaseUpgradeHistoryEntry.
        The database upgrade action.


        :param action: The action of this DatabaseUpgradeHistoryEntry.
        :type: str
        """
        allowed_values = ["PRECHECK", "UPGRADE", "ROLLBACK"]
        if not value_allowed_none_or_none_sentinel(action, allowed_values):
            action = 'UNKNOWN_ENUM_VALUE'
        self._action = action

    @property
    def source(self):
        """
        Gets the source of this DatabaseUpgradeHistoryEntry.
        The source of the Oracle Database software to be used for the upgrade.
         - Use `DB_HOME` to specify an existing Database Home to upgrade the database. The database is moved to the target Database Home and makes use of the Oracle Database software version of the target Database Home.
         - Use `DB_VERSION` to specify a generally-available Oracle Database software version to upgrade the database.
         - Use `DB_SOFTWARE_IMAGE` to specify a `database software image`__ to upgrade the database.

        __ https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/databasesoftwareimage.htm

        Allowed values for this property are: "DB_HOME", "DB_VERSION", "DB_SOFTWARE_IMAGE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The source of this DatabaseUpgradeHistoryEntry.
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this DatabaseUpgradeHistoryEntry.
        The source of the Oracle Database software to be used for the upgrade.
         - Use `DB_HOME` to specify an existing Database Home to upgrade the database. The database is moved to the target Database Home and makes use of the Oracle Database software version of the target Database Home.
         - Use `DB_VERSION` to specify a generally-available Oracle Database software version to upgrade the database.
         - Use `DB_SOFTWARE_IMAGE` to specify a `database software image`__ to upgrade the database.

        __ https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/databasesoftwareimage.htm


        :param source: The source of this DatabaseUpgradeHistoryEntry.
        :type: str
        """
        allowed_values = ["DB_HOME", "DB_VERSION", "DB_SOFTWARE_IMAGE"]
        if not value_allowed_none_or_none_sentinel(source, allowed_values):
            source = 'UNKNOWN_ENUM_VALUE'
        self._source = source

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this DatabaseUpgradeHistoryEntry.
        Status of database upgrade history SUCCEEDED|IN_PROGRESS|FAILED.

        Allowed values for this property are: "SUCCEEDED", "FAILED", "IN_PROGRESS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this DatabaseUpgradeHistoryEntry.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DatabaseUpgradeHistoryEntry.
        Status of database upgrade history SUCCEEDED|IN_PROGRESS|FAILED.


        :param lifecycle_state: The lifecycle_state of this DatabaseUpgradeHistoryEntry.
        :type: str
        """
        allowed_values = ["SUCCEEDED", "FAILED", "IN_PROGRESS"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this DatabaseUpgradeHistoryEntry.
        Additional information about the current lifecycle state.


        :return: The lifecycle_details of this DatabaseUpgradeHistoryEntry.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this DatabaseUpgradeHistoryEntry.
        Additional information about the current lifecycle state.


        :param lifecycle_details: The lifecycle_details of this DatabaseUpgradeHistoryEntry.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def target_db_version(self):
        """
        Gets the target_db_version of this DatabaseUpgradeHistoryEntry.
        A valid Oracle Database version. To get a list of supported versions, use the :func:`list_db_versions` operation.


        :return: The target_db_version of this DatabaseUpgradeHistoryEntry.
        :rtype: str
        """
        return self._target_db_version

    @target_db_version.setter
    def target_db_version(self, target_db_version):
        """
        Sets the target_db_version of this DatabaseUpgradeHistoryEntry.
        A valid Oracle Database version. To get a list of supported versions, use the :func:`list_db_versions` operation.


        :param target_db_version: The target_db_version of this DatabaseUpgradeHistoryEntry.
        :type: str
        """
        self._target_db_version = target_db_version

    @property
    def target_database_software_image_id(self):
        """
        Gets the target_database_software_image_id of this DatabaseUpgradeHistoryEntry.
        the database software image used for upgrading database.


        :return: The target_database_software_image_id of this DatabaseUpgradeHistoryEntry.
        :rtype: str
        """
        return self._target_database_software_image_id

    @target_database_software_image_id.setter
    def target_database_software_image_id(self, target_database_software_image_id):
        """
        Sets the target_database_software_image_id of this DatabaseUpgradeHistoryEntry.
        the database software image used for upgrading database.


        :param target_database_software_image_id: The target_database_software_image_id of this DatabaseUpgradeHistoryEntry.
        :type: str
        """
        self._target_database_software_image_id = target_database_software_image_id

    @property
    def target_db_home_id(self):
        """
        Gets the target_db_home_id of this DatabaseUpgradeHistoryEntry.
        The `OCID`__ of the Database Home.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The target_db_home_id of this DatabaseUpgradeHistoryEntry.
        :rtype: str
        """
        return self._target_db_home_id

    @target_db_home_id.setter
    def target_db_home_id(self, target_db_home_id):
        """
        Sets the target_db_home_id of this DatabaseUpgradeHistoryEntry.
        The `OCID`__ of the Database Home.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param target_db_home_id: The target_db_home_id of this DatabaseUpgradeHistoryEntry.
        :type: str
        """
        self._target_db_home_id = target_db_home_id

    @property
    def source_db_home_id(self):
        """
        Gets the source_db_home_id of this DatabaseUpgradeHistoryEntry.
        The `OCID`__ of the Database Home.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The source_db_home_id of this DatabaseUpgradeHistoryEntry.
        :rtype: str
        """
        return self._source_db_home_id

    @source_db_home_id.setter
    def source_db_home_id(self, source_db_home_id):
        """
        Sets the source_db_home_id of this DatabaseUpgradeHistoryEntry.
        The `OCID`__ of the Database Home.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param source_db_home_id: The source_db_home_id of this DatabaseUpgradeHistoryEntry.
        :type: str
        """
        self._source_db_home_id = source_db_home_id

    @property
    def time_started(self):
        """
        **[Required]** Gets the time_started of this DatabaseUpgradeHistoryEntry.
        The date and time when the database upgrade started.


        :return: The time_started of this DatabaseUpgradeHistoryEntry.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this DatabaseUpgradeHistoryEntry.
        The date and time when the database upgrade started.


        :param time_started: The time_started of this DatabaseUpgradeHistoryEntry.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_ended(self):
        """
        Gets the time_ended of this DatabaseUpgradeHistoryEntry.
        The date and time when the database upgrade ended.


        :return: The time_ended of this DatabaseUpgradeHistoryEntry.
        :rtype: datetime
        """
        return self._time_ended

    @time_ended.setter
    def time_ended(self, time_ended):
        """
        Sets the time_ended of this DatabaseUpgradeHistoryEntry.
        The date and time when the database upgrade ended.


        :param time_ended: The time_ended of this DatabaseUpgradeHistoryEntry.
        :type: datetime
        """
        self._time_ended = time_ended

    @property
    def options(self):
        """
        Gets the options of this DatabaseUpgradeHistoryEntry.
        Additional upgrade options supported by DBUA(Database Upgrade Assistant).
        Example: \"-upgradeTimezone false -keepEvents\"


        :return: The options of this DatabaseUpgradeHistoryEntry.
        :rtype: str
        """
        return self._options

    @options.setter
    def options(self, options):
        """
        Sets the options of this DatabaseUpgradeHistoryEntry.
        Additional upgrade options supported by DBUA(Database Upgrade Assistant).
        Example: \"-upgradeTimezone false -keepEvents\"


        :param options: The options of this DatabaseUpgradeHistoryEntry.
        :type: str
        """
        self._options = options

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HostResourceStatistics(object):
    """
    Contains host resource base statistics.
    """

    #: A constant which can be used with the resource_name property of a HostResourceStatistics.
    #: This constant has a value of "HOST_CPU_STATISTICS"
    RESOURCE_NAME_HOST_CPU_STATISTICS = "HOST_CPU_STATISTICS"

    #: A constant which can be used with the resource_name property of a HostResourceStatistics.
    #: This constant has a value of "HOST_MEMORY_STATISTICS"
    RESOURCE_NAME_HOST_MEMORY_STATISTICS = "HOST_MEMORY_STATISTICS"

    def __init__(self, **kwargs):
        """
        Initializes a new HostResourceStatistics object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.opsi.models.HostMemoryStatistics`
        * :class:`~oci.opsi.models.HostCpuStatistics`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param usage:
            The value to assign to the usage property of this HostResourceStatistics.
        :type usage: float

        :param capacity:
            The value to assign to the capacity property of this HostResourceStatistics.
        :type capacity: float

        :param utilization_percent:
            The value to assign to the utilization_percent property of this HostResourceStatistics.
        :type utilization_percent: float

        :param usage_change_percent:
            The value to assign to the usage_change_percent property of this HostResourceStatistics.
        :type usage_change_percent: float

        :param resource_name:
            The value to assign to the resource_name property of this HostResourceStatistics.
            Allowed values for this property are: "HOST_CPU_STATISTICS", "HOST_MEMORY_STATISTICS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type resource_name: str

        """
        self.swagger_types = {
            'usage': 'float',
            'capacity': 'float',
            'utilization_percent': 'float',
            'usage_change_percent': 'float',
            'resource_name': 'str'
        }

        self.attribute_map = {
            'usage': 'usage',
            'capacity': 'capacity',
            'utilization_percent': 'utilizationPercent',
            'usage_change_percent': 'usageChangePercent',
            'resource_name': 'resourceName'
        }

        self._usage = None
        self._capacity = None
        self._utilization_percent = None
        self._usage_change_percent = None
        self._resource_name = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['resourceName']

        if type == 'HOST_MEMORY_STATISTICS':
            return 'HostMemoryStatistics'

        if type == 'HOST_CPU_STATISTICS':
            return 'HostCpuStatistics'
        else:
            return 'HostResourceStatistics'

    @property
    def usage(self):
        """
        **[Required]** Gets the usage of this HostResourceStatistics.
        Total amount used of the resource metric type (CPU, STORAGE).


        :return: The usage of this HostResourceStatistics.
        :rtype: float
        """
        return self._usage

    @usage.setter
    def usage(self, usage):
        """
        Sets the usage of this HostResourceStatistics.
        Total amount used of the resource metric type (CPU, STORAGE).


        :param usage: The usage of this HostResourceStatistics.
        :type: float
        """
        self._usage = usage

    @property
    def capacity(self):
        """
        **[Required]** Gets the capacity of this HostResourceStatistics.
        The maximum allocated amount of the resource metric type  (CPU, STORAGE).


        :return: The capacity of this HostResourceStatistics.
        :rtype: float
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """
        Sets the capacity of this HostResourceStatistics.
        The maximum allocated amount of the resource metric type  (CPU, STORAGE).


        :param capacity: The capacity of this HostResourceStatistics.
        :type: float
        """
        self._capacity = capacity

    @property
    def utilization_percent(self):
        """
        **[Required]** Gets the utilization_percent of this HostResourceStatistics.
        Resource utilization in percentage.


        :return: The utilization_percent of this HostResourceStatistics.
        :rtype: float
        """
        return self._utilization_percent

    @utilization_percent.setter
    def utilization_percent(self, utilization_percent):
        """
        Sets the utilization_percent of this HostResourceStatistics.
        Resource utilization in percentage.


        :param utilization_percent: The utilization_percent of this HostResourceStatistics.
        :type: float
        """
        self._utilization_percent = utilization_percent

    @property
    def usage_change_percent(self):
        """
        **[Required]** Gets the usage_change_percent of this HostResourceStatistics.
        Change in resource utilization in percentage


        :return: The usage_change_percent of this HostResourceStatistics.
        :rtype: float
        """
        return self._usage_change_percent

    @usage_change_percent.setter
    def usage_change_percent(self, usage_change_percent):
        """
        Sets the usage_change_percent of this HostResourceStatistics.
        Change in resource utilization in percentage


        :param usage_change_percent: The usage_change_percent of this HostResourceStatistics.
        :type: float
        """
        self._usage_change_percent = usage_change_percent

    @property
    def resource_name(self):
        """
        **[Required]** Gets the resource_name of this HostResourceStatistics.
        Name of resource for host

        Allowed values for this property are: "HOST_CPU_STATISTICS", "HOST_MEMORY_STATISTICS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The resource_name of this HostResourceStatistics.
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """
        Sets the resource_name of this HostResourceStatistics.
        Name of resource for host


        :param resource_name: The resource_name of this HostResourceStatistics.
        :type: str
        """
        allowed_values = ["HOST_CPU_STATISTICS", "HOST_MEMORY_STATISTICS"]
        if not value_allowed_none_or_none_sentinel(resource_name, allowed_values):
            resource_name = 'UNKNOWN_ENUM_VALUE'
        self._resource_name = resource_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .constants import HEADER_NEXT_PAGE, HEADER_REQUEST_ID


class Response(object):
    def __init__(self,
                 status,
                 headers,
                 data,
                 request):
        """
        :param status: The HTTP status code for the Response
        :param headers: The HTTP headers for the Response
        :param data: The response data.  The type of data depends on the request.
        :param request: The corresponding request for this response.
        :param next_page: (optional) The value of the `opc-next-page` response header.
        :param request_id: (optional) The ID of the request that generated this response.
        """
        self.status = status
        """
        The HTTP status code for the Response

        :type: int
        """

        self.headers = headers
        """
        The HTTP headers for the Response

        :type: :class:`requests.structures.CaseInsensitiveDict`
        """

        self.data = data
        """
        The response data.  The type of data depends on the request.
        """

        self.request = request
        """
        The corresponding request for this response.

        :type: :class:`~oci.request.Request`
        """

        self.next_page = None
        """
        The value of the `opc-next-page` response header.

        :type: str
        """

        self.request_id = None
        """
        The ID of the request that generated this response.

        :type: str"""

        if self.headers is not None:
            self.next_page = self.headers.get(HEADER_NEXT_PAGE)
            self.request_id = self.headers.get(HEADER_REQUEST_ID)

    @property
    def has_next_page(self):
        """
        Gets a value representing whether or not there is a next page of results in a list Response.

        :rtype: bool
        """
        return self.next_page is not None



# coding: utf-8
# Modified Work: Copyright (c) 2018, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
# Original Work: Copyright (c) 2014 Adam Knight
# Original Work: Copyright (c) 2012 Adam T. Lindsay (original author)

from oci._vendor.requests.auth import AuthBase
try:
    # Python 3
    from urllib.parse import urlparse
except ImportError:
    # Python 2
    from urlparse import urlparse

from .sign import HeaderSigner


class HTTPSignatureAuth(AuthBase):
    '''
    Sign a request using the http-signature scheme.
    https://github.com/joyent/node-http-signature/blob/master/http_signing.md

    key_id is the mandatory label indicating to the server which secret to use
    secret is the filename of a pem file in the case of rsa, a password string in the case of an hmac algorithm
    algorithm is one of the six specified algorithms
    headers is a list of http headers to be included in the signing string, defaulting to "Date" alone.
    '''
    def __init__(self, key_id='', secret='', algorithm=None, headers=None):
        headers = headers or []
        self.header_signer = HeaderSigner(
            key_id=key_id,
            secret=secret,
            algorithm=algorithm,
            headers=headers
        )
        self.uses_host = 'host' in [h.lower() for h in headers]

    def __call__(self, r):
        headers = self.header_signer.sign(
            r.headers,
            # 'Host' header unavailable in request object at this point
            # if 'host' header is needed, extract it from the url
            host=urlparse(r.url).netloc if self.uses_host else None,
            method=r.method,
            path=r.path_url
        )
        r.headers.update(headers)
        return r



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from . import auth, config, constants, decorators, exceptions, regions, pagination, retry, fips
from .base_client import BaseClient
from .request import Request
from .response import Response
from .signer import Signer
from .version import __version__  # noqa
from .waiter import wait_until
import os

fips.enable_fips_mode()

if "OCI_PYTHON_SDK_NO_SERVICE_IMPORTS" in os.environ:
    pass
else:
    from . import ai_anomaly_detection, ai_language, analytics, announcements_service, apigateway, apm_control_plane, apm_synthetics, apm_traces, application_migration, artifacts, audit, autoscaling, bastion, bds, blockchain, budget, cims, cloud_guard, compute_instance_agent, container_engine, core, data_catalog, data_flow, data_integration, data_safe, data_science, database, database_management, database_migration, devops, dns, dts, email, events, file_storage, functions, generic_artifacts_content, golden_gate, healthchecks, identity, integration, jms, key_management, limits, load_balancer, log_analytics, logging, loggingingestion, loggingsearch, management_agent, management_dashboard, marketplace, monitoring, mysql, network_load_balancer, nosql, object_storage, oce, ocvp, oda, ons, operator_access_control, opsi, optimizer, os_management, resource_manager, resource_search, rover, sch, secrets, service_catalog, streaming, tenant_manager_control_plane, usage_api, vault, vulnerability_scanning, waas, work_requests

    __all__ = [
        "BaseClient", "Error", "Request", "Response", "Signer", "config", "constants", "decorators", "exceptions", "regions", "wait_until", "pagination", "auth", "retry", "fips",
        "ai_anomaly_detection", "ai_language", "analytics", "announcements_service", "apigateway", "apm_control_plane", "apm_synthetics", "apm_traces", "application_migration", "artifacts", "audit", "autoscaling", "bastion", "bds", "blockchain", "budget", "cims", "cloud_guard", "compute_instance_agent", "container_engine", "core", "data_catalog", "data_flow", "data_integration", "data_safe", "data_science", "database", "database_management", "database_migration", "devops", "dns", "dts", "email", "events", "file_storage", "functions", "generic_artifacts_content", "golden_gate", "healthchecks", "identity", "integration", "jms", "key_management", "limits", "load_balancer", "log_analytics", "logging", "loggingingestion", "loggingsearch", "management_agent", "management_dashboard", "marketplace", "monitoring", "mysql", "network_load_balancer", "nosql", "object_storage", "oce", "ocvp", "oda", "ons", "operator_access_control", "opsi", "optimizer", "os_management", "resource_manager", "resource_search", "rover", "sch", "secrets", "service_catalog", "streaming", "tenant_manager_control_plane", "usage_api", "vault", "vulnerability_scanning", "waas", "work_requests"
    ]



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AllowedParameterValue(object):
    """
    A valid value for a database parameter.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AllowedParameterValue object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param ordinal:
            The value to assign to the ordinal property of this AllowedParameterValue.
        :type ordinal: float

        :param value:
            The value to assign to the value property of this AllowedParameterValue.
        :type value: str

        :param is_default:
            The value to assign to the is_default property of this AllowedParameterValue.
        :type is_default: bool

        """
        self.swagger_types = {
            'ordinal': 'float',
            'value': 'str',
            'is_default': 'bool'
        }

        self.attribute_map = {
            'ordinal': 'ordinal',
            'value': 'value',
            'is_default': 'isDefault'
        }

        self._ordinal = None
        self._value = None
        self._is_default = None

    @property
    def ordinal(self):
        """
        Gets the ordinal of this AllowedParameterValue.
        The ordinal number in the list (1-based).


        :return: The ordinal of this AllowedParameterValue.
        :rtype: float
        """
        return self._ordinal

    @ordinal.setter
    def ordinal(self, ordinal):
        """
        Sets the ordinal of this AllowedParameterValue.
        The ordinal number in the list (1-based).


        :param ordinal: The ordinal of this AllowedParameterValue.
        :type: float
        """
        self._ordinal = ordinal

    @property
    def value(self):
        """
        Gets the value of this AllowedParameterValue.
        The parameter value at ordinal.


        :return: The value of this AllowedParameterValue.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this AllowedParameterValue.
        The parameter value at ordinal.


        :param value: The value of this AllowedParameterValue.
        :type: str
        """
        self._value = value

    @property
    def is_default(self):
        """
        Gets the is_default of this AllowedParameterValue.
        Indicates whether the given ordinal value is the default value for the parameter.


        :return: The is_default of this AllowedParameterValue.
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """
        Sets the is_default of this AllowedParameterValue.
        Indicates whether the given ordinal value is the default value for the parameter.


        :param is_default: The is_default of this AllowedParameterValue.
        :type: bool
        """
        self._is_default = is_default

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ManagedInstance(object):
    """
    Detail information for an OCI Compute instance that is being managed
    """

    #: A constant which can be used with the status property of a ManagedInstance.
    #: This constant has a value of "NORMAL"
    STATUS_NORMAL = "NORMAL"

    #: A constant which can be used with the status property of a ManagedInstance.
    #: This constant has a value of "UNREACHABLE"
    STATUS_UNREACHABLE = "UNREACHABLE"

    #: A constant which can be used with the status property of a ManagedInstance.
    #: This constant has a value of "ERROR"
    STATUS_ERROR = "ERROR"

    #: A constant which can be used with the status property of a ManagedInstance.
    #: This constant has a value of "WARNING"
    STATUS_WARNING = "WARNING"

    #: A constant which can be used with the os_family property of a ManagedInstance.
    #: This constant has a value of "LINUX"
    OS_FAMILY_LINUX = "LINUX"

    #: A constant which can be used with the os_family property of a ManagedInstance.
    #: This constant has a value of "WINDOWS"
    OS_FAMILY_WINDOWS = "WINDOWS"

    #: A constant which can be used with the os_family property of a ManagedInstance.
    #: This constant has a value of "ALL"
    OS_FAMILY_ALL = "ALL"

    def __init__(self, **kwargs):
        """
        Initializes a new ManagedInstance object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this ManagedInstance.
        :type display_name: str

        :param id:
            The value to assign to the id property of this ManagedInstance.
        :type id: str

        :param description:
            The value to assign to the description property of this ManagedInstance.
        :type description: str

        :param last_checkin:
            The value to assign to the last_checkin property of this ManagedInstance.
        :type last_checkin: str

        :param last_boot:
            The value to assign to the last_boot property of this ManagedInstance.
        :type last_boot: str

        :param updates_available:
            The value to assign to the updates_available property of this ManagedInstance.
        :type updates_available: int

        :param os_name:
            The value to assign to the os_name property of this ManagedInstance.
        :type os_name: str

        :param os_version:
            The value to assign to the os_version property of this ManagedInstance.
        :type os_version: str

        :param os_kernel_version:
            The value to assign to the os_kernel_version property of this ManagedInstance.
        :type os_kernel_version: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ManagedInstance.
        :type compartment_id: str

        :param status:
            The value to assign to the status property of this ManagedInstance.
            Allowed values for this property are: "NORMAL", "UNREACHABLE", "ERROR", "WARNING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param parent_software_source:
            The value to assign to the parent_software_source property of this ManagedInstance.
        :type parent_software_source: oci.os_management.models.SoftwareSourceId

        :param child_software_sources:
            The value to assign to the child_software_sources property of this ManagedInstance.
        :type child_software_sources: list[oci.os_management.models.SoftwareSourceId]

        :param managed_instance_groups:
            The value to assign to the managed_instance_groups property of this ManagedInstance.
        :type managed_instance_groups: list[oci.os_management.models.Id]

        :param os_family:
            The value to assign to the os_family property of this ManagedInstance.
            Allowed values for this property are: "LINUX", "WINDOWS", "ALL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type os_family: str

        :param is_reboot_required:
            The value to assign to the is_reboot_required property of this ManagedInstance.
        :type is_reboot_required: bool

        :param notification_topic_id:
            The value to assign to the notification_topic_id property of this ManagedInstance.
        :type notification_topic_id: str

        :param ksplice_effective_kernel_version:
            The value to assign to the ksplice_effective_kernel_version property of this ManagedInstance.
        :type ksplice_effective_kernel_version: str

        :param is_data_collection_authorized:
            The value to assign to the is_data_collection_authorized property of this ManagedInstance.
        :type is_data_collection_authorized: bool

        :param autonomous:
            The value to assign to the autonomous property of this ManagedInstance.
        :type autonomous: oci.os_management.models.AutonomousSettings

        :param security_updates_available:
            The value to assign to the security_updates_available property of this ManagedInstance.
        :type security_updates_available: int

        :param bug_updates_available:
            The value to assign to the bug_updates_available property of this ManagedInstance.
        :type bug_updates_available: int

        :param enhancement_updates_available:
            The value to assign to the enhancement_updates_available property of this ManagedInstance.
        :type enhancement_updates_available: int

        :param other_updates_available:
            The value to assign to the other_updates_available property of this ManagedInstance.
        :type other_updates_available: int

        :param scheduled_job_count:
            The value to assign to the scheduled_job_count property of this ManagedInstance.
        :type scheduled_job_count: int

        :param work_request_count:
            The value to assign to the work_request_count property of this ManagedInstance.
        :type work_request_count: int

        """
        self.swagger_types = {
            'display_name': 'str',
            'id': 'str',
            'description': 'str',
            'last_checkin': 'str',
            'last_boot': 'str',
            'updates_available': 'int',
            'os_name': 'str',
            'os_version': 'str',
            'os_kernel_version': 'str',
            'compartment_id': 'str',
            'status': 'str',
            'parent_software_source': 'SoftwareSourceId',
            'child_software_sources': 'list[SoftwareSourceId]',
            'managed_instance_groups': 'list[Id]',
            'os_family': 'str',
            'is_reboot_required': 'bool',
            'notification_topic_id': 'str',
            'ksplice_effective_kernel_version': 'str',
            'is_data_collection_authorized': 'bool',
            'autonomous': 'AutonomousSettings',
            'security_updates_available': 'int',
            'bug_updates_available': 'int',
            'enhancement_updates_available': 'int',
            'other_updates_available': 'int',
            'scheduled_job_count': 'int',
            'work_request_count': 'int'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'id': 'id',
            'description': 'description',
            'last_checkin': 'lastCheckin',
            'last_boot': 'lastBoot',
            'updates_available': 'updatesAvailable',
            'os_name': 'osName',
            'os_version': 'osVersion',
            'os_kernel_version': 'osKernelVersion',
            'compartment_id': 'compartmentId',
            'status': 'status',
            'parent_software_source': 'parentSoftwareSource',
            'child_software_sources': 'childSoftwareSources',
            'managed_instance_groups': 'managedInstanceGroups',
            'os_family': 'osFamily',
            'is_reboot_required': 'isRebootRequired',
            'notification_topic_id': 'notificationTopicId',
            'ksplice_effective_kernel_version': 'kspliceEffectiveKernelVersion',
            'is_data_collection_authorized': 'isDataCollectionAuthorized',
            'autonomous': 'autonomous',
            'security_updates_available': 'securityUpdatesAvailable',
            'bug_updates_available': 'bugUpdatesAvailable',
            'enhancement_updates_available': 'enhancementUpdatesAvailable',
            'other_updates_available': 'otherUpdatesAvailable',
            'scheduled_job_count': 'scheduledJobCount',
            'work_request_count': 'workRequestCount'
        }

        self._display_name = None
        self._id = None
        self._description = None
        self._last_checkin = None
        self._last_boot = None
        self._updates_available = None
        self._os_name = None
        self._os_version = None
        self._os_kernel_version = None
        self._compartment_id = None
        self._status = None
        self._parent_software_source = None
        self._child_software_sources = None
        self._managed_instance_groups = None
        self._os_family = None
        self._is_reboot_required = None
        self._notification_topic_id = None
        self._ksplice_effective_kernel_version = None
        self._is_data_collection_authorized = None
        self._autonomous = None
        self._security_updates_available = None
        self._bug_updates_available = None
        self._enhancement_updates_available = None
        self._other_updates_available = None
        self._scheduled_job_count = None
        self._work_request_count = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ManagedInstance.
        Managed Instance identifier


        :return: The display_name of this ManagedInstance.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ManagedInstance.
        Managed Instance identifier


        :param display_name: The display_name of this ManagedInstance.
        :type: str
        """
        self._display_name = display_name

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ManagedInstance.
        OCID for the managed instance


        :return: The id of this ManagedInstance.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ManagedInstance.
        OCID for the managed instance


        :param id: The id of this ManagedInstance.
        :type: str
        """
        self._id = id

    @property
    def description(self):
        """
        Gets the description of this ManagedInstance.
        Information specified by the user about the managed instance


        :return: The description of this ManagedInstance.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ManagedInstance.
        Information specified by the user about the managed instance


        :param description: The description of this ManagedInstance.
        :type: str
        """
        self._description = description

    @property
    def last_checkin(self):
        """
        Gets the last_checkin of this ManagedInstance.
        Time at which the instance last checked in


        :return: The last_checkin of this ManagedInstance.
        :rtype: str
        """
        return self._last_checkin

    @last_checkin.setter
    def last_checkin(self, last_checkin):
        """
        Sets the last_checkin of this ManagedInstance.
        Time at which the instance last checked in


        :param last_checkin: The last_checkin of this ManagedInstance.
        :type: str
        """
        self._last_checkin = last_checkin

    @property
    def last_boot(self):
        """
        Gets the last_boot of this ManagedInstance.
        Time at which the instance last booted


        :return: The last_boot of this ManagedInstance.
        :rtype: str
        """
        return self._last_boot

    @last_boot.setter
    def last_boot(self, last_boot):
        """
        Sets the last_boot of this ManagedInstance.
        Time at which the instance last booted


        :param last_boot: The last_boot of this ManagedInstance.
        :type: str
        """
        self._last_boot = last_boot

    @property
    def updates_available(self):
        """
        Gets the updates_available of this ManagedInstance.
        Number of updates available to be installed


        :return: The updates_available of this ManagedInstance.
        :rtype: int
        """
        return self._updates_available

    @updates_available.setter
    def updates_available(self, updates_available):
        """
        Sets the updates_available of this ManagedInstance.
        Number of updates available to be installed


        :param updates_available: The updates_available of this ManagedInstance.
        :type: int
        """
        self._updates_available = updates_available

    @property
    def os_name(self):
        """
        Gets the os_name of this ManagedInstance.
        Operating System Name


        :return: The os_name of this ManagedInstance.
        :rtype: str
        """
        return self._os_name

    @os_name.setter
    def os_name(self, os_name):
        """
        Sets the os_name of this ManagedInstance.
        Operating System Name


        :param os_name: The os_name of this ManagedInstance.
        :type: str
        """
        self._os_name = os_name

    @property
    def os_version(self):
        """
        Gets the os_version of this ManagedInstance.
        Operating System Version


        :return: The os_version of this ManagedInstance.
        :rtype: str
        """
        return self._os_version

    @os_version.setter
    def os_version(self, os_version):
        """
        Sets the os_version of this ManagedInstance.
        Operating System Version


        :param os_version: The os_version of this ManagedInstance.
        :type: str
        """
        self._os_version = os_version

    @property
    def os_kernel_version(self):
        """
        Gets the os_kernel_version of this ManagedInstance.
        Operating System Kernel Version


        :return: The os_kernel_version of this ManagedInstance.
        :rtype: str
        """
        return self._os_kernel_version

    @os_kernel_version.setter
    def os_kernel_version(self, os_kernel_version):
        """
        Sets the os_kernel_version of this ManagedInstance.
        Operating System Kernel Version


        :param os_kernel_version: The os_kernel_version of this ManagedInstance.
        :type: str
        """
        self._os_kernel_version = os_kernel_version

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ManagedInstance.
        OCID for the Compartment


        :return: The compartment_id of this ManagedInstance.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ManagedInstance.
        OCID for the Compartment


        :param compartment_id: The compartment_id of this ManagedInstance.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def status(self):
        """
        Gets the status of this ManagedInstance.
        status of the managed instance.

        Allowed values for this property are: "NORMAL", "UNREACHABLE", "ERROR", "WARNING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this ManagedInstance.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this ManagedInstance.
        status of the managed instance.


        :param status: The status of this ManagedInstance.
        :type: str
        """
        allowed_values = ["NORMAL", "UNREACHABLE", "ERROR", "WARNING"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def parent_software_source(self):
        """
        Gets the parent_software_source of this ManagedInstance.
        the parent (base) Software Source attached to the Managed Instance


        :return: The parent_software_source of this ManagedInstance.
        :rtype: oci.os_management.models.SoftwareSourceId
        """
        return self._parent_software_source

    @parent_software_source.setter
    def parent_software_source(self, parent_software_source):
        """
        Sets the parent_software_source of this ManagedInstance.
        the parent (base) Software Source attached to the Managed Instance


        :param parent_software_source: The parent_software_source of this ManagedInstance.
        :type: oci.os_management.models.SoftwareSourceId
        """
        self._parent_software_source = parent_software_source

    @property
    def child_software_sources(self):
        """
        Gets the child_software_sources of this ManagedInstance.
        list of child Software Sources attached to the Managed Instance


        :return: The child_software_sources of this ManagedInstance.
        :rtype: list[oci.os_management.models.SoftwareSourceId]
        """
        return self._child_software_sources

    @child_software_sources.setter
    def child_software_sources(self, child_software_sources):
        """
        Sets the child_software_sources of this ManagedInstance.
        list of child Software Sources attached to the Managed Instance


        :param child_software_sources: The child_software_sources of this ManagedInstance.
        :type: list[oci.os_management.models.SoftwareSourceId]
        """
        self._child_software_sources = child_software_sources

    @property
    def managed_instance_groups(self):
        """
        Gets the managed_instance_groups of this ManagedInstance.
        The ids of the managed instance groups of which this instance is a
        member.


        :return: The managed_instance_groups of this ManagedInstance.
        :rtype: list[oci.os_management.models.Id]
        """
        return self._managed_instance_groups

    @managed_instance_groups.setter
    def managed_instance_groups(self, managed_instance_groups):
        """
        Sets the managed_instance_groups of this ManagedInstance.
        The ids of the managed instance groups of which this instance is a
        member.


        :param managed_instance_groups: The managed_instance_groups of this ManagedInstance.
        :type: list[oci.os_management.models.Id]
        """
        self._managed_instance_groups = managed_instance_groups

    @property
    def os_family(self):
        """
        Gets the os_family of this ManagedInstance.
        The Operating System type of the managed instance.

        Allowed values for this property are: "LINUX", "WINDOWS", "ALL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The os_family of this ManagedInstance.
        :rtype: str
        """
        return self._os_family

    @os_family.setter
    def os_family(self, os_family):
        """
        Sets the os_family of this ManagedInstance.
        The Operating System type of the managed instance.


        :param os_family: The os_family of this ManagedInstance.
        :type: str
        """
        allowed_values = ["LINUX", "WINDOWS", "ALL"]
        if not value_allowed_none_or_none_sentinel(os_family, allowed_values):
            os_family = 'UNKNOWN_ENUM_VALUE'
        self._os_family = os_family

    @property
    def is_reboot_required(self):
        """
        Gets the is_reboot_required of this ManagedInstance.
        Indicates whether a reboot is required to complete installation of updates.


        :return: The is_reboot_required of this ManagedInstance.
        :rtype: bool
        """
        return self._is_reboot_required

    @is_reboot_required.setter
    def is_reboot_required(self, is_reboot_required):
        """
        Sets the is_reboot_required of this ManagedInstance.
        Indicates whether a reboot is required to complete installation of updates.


        :param is_reboot_required: The is_reboot_required of this ManagedInstance.
        :type: bool
        """
        self._is_reboot_required = is_reboot_required

    @property
    def notification_topic_id(self):
        """
        Gets the notification_topic_id of this ManagedInstance.
        OCID of the ONS topic used to send notification to users


        :return: The notification_topic_id of this ManagedInstance.
        :rtype: str
        """
        return self._notification_topic_id

    @notification_topic_id.setter
    def notification_topic_id(self, notification_topic_id):
        """
        Sets the notification_topic_id of this ManagedInstance.
        OCID of the ONS topic used to send notification to users


        :param notification_topic_id: The notification_topic_id of this ManagedInstance.
        :type: str
        """
        self._notification_topic_id = notification_topic_id

    @property
    def ksplice_effective_kernel_version(self):
        """
        Gets the ksplice_effective_kernel_version of this ManagedInstance.
        The ksplice effective kernel version


        :return: The ksplice_effective_kernel_version of this ManagedInstance.
        :rtype: str
        """
        return self._ksplice_effective_kernel_version

    @ksplice_effective_kernel_version.setter
    def ksplice_effective_kernel_version(self, ksplice_effective_kernel_version):
        """
        Sets the ksplice_effective_kernel_version of this ManagedInstance.
        The ksplice effective kernel version


        :param ksplice_effective_kernel_version: The ksplice_effective_kernel_version of this ManagedInstance.
        :type: str
        """
        self._ksplice_effective_kernel_version = ksplice_effective_kernel_version

    @property
    def is_data_collection_authorized(self):
        """
        Gets the is_data_collection_authorized of this ManagedInstance.
        True if user allow data collection for this instance


        :return: The is_data_collection_authorized of this ManagedInstance.
        :rtype: bool
        """
        return self._is_data_collection_authorized

    @is_data_collection_authorized.setter
    def is_data_collection_authorized(self, is_data_collection_authorized):
        """
        Sets the is_data_collection_authorized of this ManagedInstance.
        True if user allow data collection for this instance


        :param is_data_collection_authorized: The is_data_collection_authorized of this ManagedInstance.
        :type: bool
        """
        self._is_data_collection_authorized = is_data_collection_authorized

    @property
    def autonomous(self):
        """
        Gets the autonomous of this ManagedInstance.
        if present, indicates the Managed Instance is an autonomous instance. Holds all the Autonomous specific information


        :return: The autonomous of this ManagedInstance.
        :rtype: oci.os_management.models.AutonomousSettings
        """
        return self._autonomous

    @autonomous.setter
    def autonomous(self, autonomous):
        """
        Sets the autonomous of this ManagedInstance.
        if present, indicates the Managed Instance is an autonomous instance. Holds all the Autonomous specific information


        :param autonomous: The autonomous of this ManagedInstance.
        :type: oci.os_management.models.AutonomousSettings
        """
        self._autonomous = autonomous

    @property
    def security_updates_available(self):
        """
        Gets the security_updates_available of this ManagedInstance.
        Number of security type updates available to be installed


        :return: The security_updates_available of this ManagedInstance.
        :rtype: int
        """
        return self._security_updates_available

    @security_updates_available.setter
    def security_updates_available(self, security_updates_available):
        """
        Sets the security_updates_available of this ManagedInstance.
        Number of security type updates available to be installed


        :param security_updates_available: The security_updates_available of this ManagedInstance.
        :type: int
        """
        self._security_updates_available = security_updates_available

    @property
    def bug_updates_available(self):
        """
        Gets the bug_updates_available of this ManagedInstance.
        Number of bug fix type updates available to be installed


        :return: The bug_updates_available of this ManagedInstance.
        :rtype: int
        """
        return self._bug_updates_available

    @bug_updates_available.setter
    def bug_updates_available(self, bug_updates_available):
        """
        Sets the bug_updates_available of this ManagedInstance.
        Number of bug fix type updates available to be installed


        :param bug_updates_available: The bug_updates_available of this ManagedInstance.
        :type: int
        """
        self._bug_updates_available = bug_updates_available

    @property
    def enhancement_updates_available(self):
        """
        Gets the enhancement_updates_available of this ManagedInstance.
        Number of enhancement type updates available to be installed


        :return: The enhancement_updates_available of this ManagedInstance.
        :rtype: int
        """
        return self._enhancement_updates_available

    @enhancement_updates_available.setter
    def enhancement_updates_available(self, enhancement_updates_available):
        """
        Sets the enhancement_updates_available of this ManagedInstance.
        Number of enhancement type updates available to be installed


        :param enhancement_updates_available: The enhancement_updates_available of this ManagedInstance.
        :type: int
        """
        self._enhancement_updates_available = enhancement_updates_available

    @property
    def other_updates_available(self):
        """
        Gets the other_updates_available of this ManagedInstance.
        Number of non-classified updates available to be installed


        :return: The other_updates_available of this ManagedInstance.
        :rtype: int
        """
        return self._other_updates_available

    @other_updates_available.setter
    def other_updates_available(self, other_updates_available):
        """
        Sets the other_updates_available of this ManagedInstance.
        Number of non-classified updates available to be installed


        :param other_updates_available: The other_updates_available of this ManagedInstance.
        :type: int
        """
        self._other_updates_available = other_updates_available

    @property
    def scheduled_job_count(self):
        """
        Gets the scheduled_job_count of this ManagedInstance.
        Number of scheduled jobs associated with this instance


        :return: The scheduled_job_count of this ManagedInstance.
        :rtype: int
        """
        return self._scheduled_job_count

    @scheduled_job_count.setter
    def scheduled_job_count(self, scheduled_job_count):
        """
        Sets the scheduled_job_count of this ManagedInstance.
        Number of scheduled jobs associated with this instance


        :param scheduled_job_count: The scheduled_job_count of this ManagedInstance.
        :type: int
        """
        self._scheduled_job_count = scheduled_job_count

    @property
    def work_request_count(self):
        """
        Gets the work_request_count of this ManagedInstance.
        Number of work requests associated with this instance


        :return: The work_request_count of this ManagedInstance.
        :rtype: int
        """
        return self._work_request_count

    @work_request_count.setter
    def work_request_count(self, work_request_count):
        """
        Sets the work_request_count of this ManagedInstance.
        Number of work requests associated with this instance


        :param work_request_count: The work_request_count of this ManagedInstance.
        :type: int
        """
        self._work_request_count = work_request_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResolverSummary(object):
    """
    An OCI DNS resolver. If the resolver has an attached VCN, the VCN will attempt to answer queries based on the
    attached views in priority order. If the query does not match any of the attached views, the query will be
    evaluated against the default view. If the default view does not match, the rules will be evaluated in
    priority order. If no rules match the query, answers come from Internet DNS. A resolver may have a maximum of 10
    resolver endpoints.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    #: A constant which can be used with the lifecycle_state property of a ResolverSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ResolverSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a ResolverSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a ResolverSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a ResolverSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a ResolverSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    def __init__(self, **kwargs):
        """
        Initializes a new ResolverSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this ResolverSummary.
        :type compartment_id: str

        :param attached_vcn_id:
            The value to assign to the attached_vcn_id property of this ResolverSummary.
        :type attached_vcn_id: str

        :param display_name:
            The value to assign to the display_name property of this ResolverSummary.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ResolverSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this ResolverSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param id:
            The value to assign to the id property of this ResolverSummary.
        :type id: str

        :param time_created:
            The value to assign to the time_created property of this ResolverSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this ResolverSummary.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ResolverSummary.
            Allowed values for this property are: "ACTIVE", "CREATING", "DELETED", "DELETING", "FAILED", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param _self:
            The value to assign to the _self property of this ResolverSummary.
        :type _self: str

        :param default_view_id:
            The value to assign to the default_view_id property of this ResolverSummary.
        :type default_view_id: str

        :param is_protected:
            The value to assign to the is_protected property of this ResolverSummary.
        :type is_protected: bool

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'attached_vcn_id': 'str',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'id': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            '_self': 'str',
            'default_view_id': 'str',
            'is_protected': 'bool'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'attached_vcn_id': 'attachedVcnId',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'id': 'id',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            '_self': 'self',
            'default_view_id': 'defaultViewId',
            'is_protected': 'isProtected'
        }

        self._compartment_id = None
        self._attached_vcn_id = None
        self._display_name = None
        self._freeform_tags = None
        self._defined_tags = None
        self._id = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self.__self = None
        self._default_view_id = None
        self._is_protected = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ResolverSummary.
        The OCID of the owning compartment.


        :return: The compartment_id of this ResolverSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ResolverSummary.
        The OCID of the owning compartment.


        :param compartment_id: The compartment_id of this ResolverSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def attached_vcn_id(self):
        """
        Gets the attached_vcn_id of this ResolverSummary.
        The OCID of the attached VCN.


        :return: The attached_vcn_id of this ResolverSummary.
        :rtype: str
        """
        return self._attached_vcn_id

    @attached_vcn_id.setter
    def attached_vcn_id(self, attached_vcn_id):
        """
        Sets the attached_vcn_id of this ResolverSummary.
        The OCID of the attached VCN.


        :param attached_vcn_id: The attached_vcn_id of this ResolverSummary.
        :type: str
        """
        self._attached_vcn_id = attached_vcn_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ResolverSummary.
        The display name of the resolver.


        :return: The display_name of this ResolverSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ResolverSummary.
        The display name of the resolver.


        :param display_name: The display_name of this ResolverSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        **[Required]** Gets the freeform_tags of this ResolverSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.


        **Example:** `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this ResolverSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this ResolverSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.


        **Example:** `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this ResolverSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        **[Required]** Gets the defined_tags of this ResolverSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.


        **Example:** `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this ResolverSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this ResolverSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.


        **Example:** `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this ResolverSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ResolverSummary.
        The OCID of the resolver.


        :return: The id of this ResolverSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ResolverSummary.
        The OCID of the resolver.


        :param id: The id of this ResolverSummary.
        :type: str
        """
        self._id = id

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ResolverSummary.
        The date and time the resource was created in \"YYYY-MM-ddThh:mm:ssZ\" format
        with a Z offset, as defined by RFC 3339.

        **Example:** `2016-07-22T17:23:59:60Z`


        :return: The time_created of this ResolverSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ResolverSummary.
        The date and time the resource was created in \"YYYY-MM-ddThh:mm:ssZ\" format
        with a Z offset, as defined by RFC 3339.

        **Example:** `2016-07-22T17:23:59:60Z`


        :param time_created: The time_created of this ResolverSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this ResolverSummary.
        The date and time the resource was last updated in \"YYYY-MM-ddThh:mm:ssZ\"
        format with a Z offset, as defined by RFC 3339.

        **Example:** `2016-07-22T17:23:59:60Z`


        :return: The time_updated of this ResolverSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this ResolverSummary.
        The date and time the resource was last updated in \"YYYY-MM-ddThh:mm:ssZ\"
        format with a Z offset, as defined by RFC 3339.

        **Example:** `2016-07-22T17:23:59:60Z`


        :param time_updated: The time_updated of this ResolverSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this ResolverSummary.
        The current state of the resource.

        Allowed values for this property are: "ACTIVE", "CREATING", "DELETED", "DELETING", "FAILED", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this ResolverSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ResolverSummary.
        The current state of the resource.


        :param lifecycle_state: The lifecycle_state of this ResolverSummary.
        :type: str
        """
        allowed_values = ["ACTIVE", "CREATING", "DELETED", "DELETING", "FAILED", "UPDATING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def _self(self):
        """
        **[Required]** Gets the _self of this ResolverSummary.
        The canonical absolute URL of the resource.


        :return: The _self of this ResolverSummary.
        :rtype: str
        """
        return self.__self

    @_self.setter
    def _self(self, _self):
        """
        Sets the _self of this ResolverSummary.
        The canonical absolute URL of the resource.


        :param _self: The _self of this ResolverSummary.
        :type: str
        """
        self.__self = _self

    @property
    def default_view_id(self):
        """
        Gets the default_view_id of this ResolverSummary.
        The OCID of the default view.


        :return: The default_view_id of this ResolverSummary.
        :rtype: str
        """
        return self._default_view_id

    @default_view_id.setter
    def default_view_id(self, default_view_id):
        """
        Sets the default_view_id of this ResolverSummary.
        The OCID of the default view.


        :param default_view_id: The default_view_id of this ResolverSummary.
        :type: str
        """
        self._default_view_id = default_view_id

    @property
    def is_protected(self):
        """
        **[Required]** Gets the is_protected of this ResolverSummary.
        A Boolean flag indicating whether or not parts of the resource are unable to be explicitly managed.


        :return: The is_protected of this ResolverSummary.
        :rtype: bool
        """
        return self._is_protected

    @is_protected.setter
    def is_protected(self, is_protected):
        """
        Sets the is_protected of this ResolverSummary.
        A Boolean flag indicating whether or not parts of the resource are unable to be explicitly managed.


        :param is_protected: The is_protected of this ResolverSummary.
        :type: bool
        """
        self._is_protected = is_protected

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .backend import Backend
from .backend_collection import BackendCollection
from .backend_details import BackendDetails
from .backend_health import BackendHealth
from .backend_set import BackendSet
from .backend_set_collection import BackendSetCollection
from .backend_set_details import BackendSetDetails
from .backend_set_health import BackendSetHealth
from .backend_set_summary import BackendSetSummary
from .backend_summary import BackendSummary
from .change_network_load_balancer_compartment_details import ChangeNetworkLoadBalancerCompartmentDetails
from .create_backend_details import CreateBackendDetails
from .create_backend_set_details import CreateBackendSetDetails
from .create_listener_details import CreateListenerDetails
from .create_network_load_balancer_details import CreateNetworkLoadBalancerDetails
from .health_check_result import HealthCheckResult
from .health_checker import HealthChecker
from .health_checker_details import HealthCheckerDetails
from .ip_address import IpAddress
from .listener import Listener
from .listener_collection import ListenerCollection
from .listener_details import ListenerDetails
from .listener_summary import ListenerSummary
from .network_load_balancer import NetworkLoadBalancer
from .network_load_balancer_collection import NetworkLoadBalancerCollection
from .network_load_balancer_health import NetworkLoadBalancerHealth
from .network_load_balancer_health_collection import NetworkLoadBalancerHealthCollection
from .network_load_balancer_health_summary import NetworkLoadBalancerHealthSummary
from .network_load_balancer_summary import NetworkLoadBalancerSummary
from .network_load_balancers_policy_collection import NetworkLoadBalancersPolicyCollection
from .network_load_balancers_protocol_collection import NetworkLoadBalancersProtocolCollection
from .reserved_ip import ReservedIP
from .update_backend_details import UpdateBackendDetails
from .update_backend_set_details import UpdateBackendSetDetails
from .update_health_checker_details import UpdateHealthCheckerDetails
from .update_listener_details import UpdateListenerDetails
from .update_network_load_balancer_details import UpdateNetworkLoadBalancerDetails
from .update_network_security_groups_details import UpdateNetworkSecurityGroupsDetails
from .work_request import WorkRequest
from .work_request_collection import WorkRequestCollection
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for network_load_balancer services.
network_load_balancer_type_mapping = {
    "Backend": Backend,
    "BackendCollection": BackendCollection,
    "BackendDetails": BackendDetails,
    "BackendHealth": BackendHealth,
    "BackendSet": BackendSet,
    "BackendSetCollection": BackendSetCollection,
    "BackendSetDetails": BackendSetDetails,
    "BackendSetHealth": BackendSetHealth,
    "BackendSetSummary": BackendSetSummary,
    "BackendSummary": BackendSummary,
    "ChangeNetworkLoadBalancerCompartmentDetails": ChangeNetworkLoadBalancerCompartmentDetails,
    "CreateBackendDetails": CreateBackendDetails,
    "CreateBackendSetDetails": CreateBackendSetDetails,
    "CreateListenerDetails": CreateListenerDetails,
    "CreateNetworkLoadBalancerDetails": CreateNetworkLoadBalancerDetails,
    "HealthCheckResult": HealthCheckResult,
    "HealthChecker": HealthChecker,
    "HealthCheckerDetails": HealthCheckerDetails,
    "IpAddress": IpAddress,
    "Listener": Listener,
    "ListenerCollection": ListenerCollection,
    "ListenerDetails": ListenerDetails,
    "ListenerSummary": ListenerSummary,
    "NetworkLoadBalancer": NetworkLoadBalancer,
    "NetworkLoadBalancerCollection": NetworkLoadBalancerCollection,
    "NetworkLoadBalancerHealth": NetworkLoadBalancerHealth,
    "NetworkLoadBalancerHealthCollection": NetworkLoadBalancerHealthCollection,
    "NetworkLoadBalancerHealthSummary": NetworkLoadBalancerHealthSummary,
    "NetworkLoadBalancerSummary": NetworkLoadBalancerSummary,
    "NetworkLoadBalancersPolicyCollection": NetworkLoadBalancersPolicyCollection,
    "NetworkLoadBalancersProtocolCollection": NetworkLoadBalancersProtocolCollection,
    "ReservedIP": ReservedIP,
    "UpdateBackendDetails": UpdateBackendDetails,
    "UpdateBackendSetDetails": UpdateBackendSetDetails,
    "UpdateHealthCheckerDetails": UpdateHealthCheckerDetails,
    "UpdateListenerDetails": UpdateListenerDetails,
    "UpdateNetworkLoadBalancerDetails": UpdateNetworkLoadBalancerDetails,
    "UpdateNetworkSecurityGroupsDetails": UpdateNetworkSecurityGroupsDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestCollection": WorkRequestCollection,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from oci._vendor import requests  # noqa: F401
from oci._vendor import six

from oci import retry  # noqa: F401
from oci.base_client import BaseClient
from oci.config import get_config_value_or_default, validate_config
from oci.signer import Signer
from oci.util import Sentinel, get_signer_from_authentication_type, AUTHENTICATION_TYPE_FIELD_NAME
from .models import secrets_type_mapping
missing = Sentinel("Missing")


class SecretsClient(object):
    """
    API for retrieving secrets from vaults.
    """

    def __init__(self, config, **kwargs):
        """
        Creates a new service client

        :param dict config:
            Configuration keys and values as per `SDK and Tool Configuration <https://docs.cloud.oracle.com/Content/API/Concepts/sdkconfig.htm>`__.
            The :py:meth:`~oci.config.from_file` method can be used to load configuration from a file. Alternatively, a ``dict`` can be passed. You can validate_config
            the dict using :py:meth:`~oci.config.validate_config`

        :param str service_endpoint: (optional)
            The endpoint of the service to call using this client. For example ``https://iaas.us-ashburn-1.oraclecloud.com``. If this keyword argument is
            not provided then it will be derived using the region in the config parameter. You should only provide this keyword argument if you have an explicit
            need to specify a service endpoint.

        :param timeout: (optional)
            The connection and read timeouts for the client. The default values are connection timeout 10 seconds and read timeout 60 seconds. This keyword argument can be provided
            as a single float, in which case the value provided is used for both the read and connection timeouts, or as a tuple of two floats. If
            a tuple is provided then the first value is used as the connection timeout and the second value as the read timeout.
        :type timeout: float or tuple(float, float)

        :param signer: (optional)
            The signer to use when signing requests made by the service client. The default is to use a :py:class:`~oci.signer.Signer` based on the values
            provided in the config parameter.

            One use case for this parameter is for `Instance Principals authentication <https://docs.cloud.oracle.com/Content/Identity/Tasks/callingservicesfrominstances.htm>`__
            by passing an instance of :py:class:`~oci.auth.signers.InstancePrincipalsSecurityTokenSigner` as the value for this keyword argument
        :type signer: :py:class:`~oci.signer.AbstractBaseSigner`

        :param obj retry_strategy: (optional)
            A retry strategy to apply to all calls made by this service client (i.e. at the client level). There is no retry strategy applied by default.
            Retry strategies can also be applied at the operation level by passing a ``retry_strategy`` keyword argument as part of calling the operation.
            Any value provided at the operation level will override whatever is specified at the client level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.
        """
        validate_config(config, signer=kwargs.get('signer'))
        if 'signer' in kwargs:
            signer = kwargs['signer']

        elif AUTHENTICATION_TYPE_FIELD_NAME in config:
            signer = get_signer_from_authentication_type(config)

        else:
            signer = Signer(
                tenancy=config["tenancy"],
                user=config["user"],
                fingerprint=config["fingerprint"],
                private_key_file_location=config.get("key_file"),
                pass_phrase=get_config_value_or_default(config, "pass_phrase"),
                private_key_content=config.get("key_content")
            )

        base_client_init_kwargs = {
            'regional_client': True,
            'service_endpoint': kwargs.get('service_endpoint'),
            'base_path': '/20190301',
            'service_endpoint_template': 'https://secrets.vaults.{region}.oci.{secondLevelDomain}',
            'skip_deserialization': kwargs.get('skip_deserialization', False)
        }
        if 'timeout' in kwargs:
            base_client_init_kwargs['timeout'] = kwargs.get('timeout')
        self.base_client = BaseClient("secrets", config, signer, secrets_type_mapping, **base_client_init_kwargs)
        self.retry_strategy = kwargs.get('retry_strategy')

    def get_secret_bundle(self, secret_id, **kwargs):
        """
        Gets a secret bundle that matches either the specified `stage`, `secretVersionName`, or `versionNumber` parameter.
        If none of these parameters are provided, the bundle for the secret version marked as `CURRENT` will be returned.


        :param str secret_id: (required)
            The OCID of the secret.

        :param str opc_request_id: (optional)
            Unique identifier for the request.

        :param int version_number: (optional)
            The version number of the secret.

        :param str secret_version_name: (optional)
            The name of the secret. (This might be referred to as the name of the secret version. Names are unique across the different versions of a secret.)

        :param str stage: (optional)
            The rotation state of the secret version.

            Allowed values are: "CURRENT", "PENDING", "LATEST", "PREVIOUS", "DEPRECATED"

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.secrets.models.SecretBundle`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/secrets/get_secret_bundle.py.html>`__ to see an example of how to use get_secret_bundle API.
        """
        resource_path = "/secretbundles/{secretId}"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_request_id",
            "version_number",
            "secret_version_name",
            "stage"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "get_secret_bundle got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "secretId": secret_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        if 'stage' in kwargs:
            stage_allowed_values = ["CURRENT", "PENDING", "LATEST", "PREVIOUS", "DEPRECATED"]
            if kwargs['stage'] not in stage_allowed_values:
                raise ValueError(
                    "Invalid value for `stage`, must be one of {0}".format(stage_allowed_values)
                )

        query_params = {
            "versionNumber": kwargs.get("version_number", missing),
            "secretVersionName": kwargs.get("secret_version_name", missing),
            "stage": kwargs.get("stage", missing)
        }
        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                query_params=query_params,
                header_params=header_params,
                response_type="SecretBundle")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                query_params=query_params,
                header_params=header_params,
                response_type="SecretBundle")

    def get_secret_bundle_by_name(self, secret_name, vault_id, **kwargs):
        """
        Gets a secret bundle by secret name and vault ID, and secret version that matches either the specified `stage`, `secretVersionName`, or `versionNumber` parameter.
        If none of these parameters are provided, the bundle for the secret version marked as `CURRENT` is returned.


        :param str secret_name: (required)
            A user-friendly name for the secret. Secret names are unique within a vault. Secret names are case-sensitive.

        :param str vault_id: (required)
            The OCID of the vault that contains the secret.

        :param str opc_request_id: (optional)
            Unique identifier for the request.

        :param int version_number: (optional)
            The version number of the secret.

        :param str secret_version_name: (optional)
            The name of the secret. (This might be referred to as the name of the secret version. Names are unique across the different versions of a secret.)

        :param str stage: (optional)
            The rotation state of the secret version.

            Allowed values are: "CURRENT", "PENDING", "LATEST", "PREVIOUS", "DEPRECATED"

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.secrets.models.SecretBundle`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/secrets/get_secret_bundle_by_name.py.html>`__ to see an example of how to use get_secret_bundle_by_name API.
        """
        resource_path = "/secretbundles/actions/getByName"
        method = "POST"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_request_id",
            "version_number",
            "secret_version_name",
            "stage"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "get_secret_bundle_by_name got unknown kwargs: {!r}".format(extra_kwargs))

        if 'stage' in kwargs:
            stage_allowed_values = ["CURRENT", "PENDING", "LATEST", "PREVIOUS", "DEPRECATED"]
            if kwargs['stage'] not in stage_allowed_values:
                raise ValueError(
                    "Invalid value for `stage`, must be one of {0}".format(stage_allowed_values)
                )

        query_params = {
            "secretName": secret_name,
            "vaultId": vault_id,
            "versionNumber": kwargs.get("version_number", missing),
            "secretVersionName": kwargs.get("secret_version_name", missing),
            "stage": kwargs.get("stage", missing)
        }
        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="SecretBundle")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="SecretBundle")

    def list_secret_bundle_versions(self, secret_id, **kwargs):
        """
        Lists all secret bundle versions for the specified secret.


        :param str secret_id: (required)
            The OCID of the secret.

        :param str opc_request_id: (optional)
            Unique identifier for the request.

        :param int limit: (optional)
            The maximum number of items to return in a paginated \"List\" call. For information about pagination, see
            `List Pagination`__.

            __ https://docs.cloud.oracle.com/#API/Concepts/usingapi.htm#List_Pagination

        :param str page: (optional)
            The value of the `opc-next-page` response header from the previous \"List\" call. For information about
            pagination, see `List Pagination`__.

            __ https://docs.cloud.oracle.com/#API/Concepts/usingapi.htm#List_Pagination

        :param str sort_by: (optional)
            The field to sort by. You can specify only one sort order. The default
            order for `VERSION_NUMBER` is ascending.

            Allowed values are: "VERSION_NUMBER"

        :param str sort_order: (optional)
            The sort order to use, either ascending (`ASC`) or descending (`DESC`).

            Allowed values are: "ASC", "DESC"

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type list of :class:`~oci.secrets.models.SecretBundleVersionSummary`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/secrets/list_secret_bundle_versions.py.html>`__ to see an example of how to use list_secret_bundle_versions API.
        """
        resource_path = "/secretbundles/{secretId}/versions"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_request_id",
            "limit",
            "page",
            "sort_by",
            "sort_order"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "list_secret_bundle_versions got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "secretId": secret_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        if 'sort_by' in kwargs:
            sort_by_allowed_values = ["VERSION_NUMBER"]
            if kwargs['sort_by'] not in sort_by_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_by`, must be one of {0}".format(sort_by_allowed_values)
                )

        if 'sort_order' in kwargs:
            sort_order_allowed_values = ["ASC", "DESC"]
            if kwargs['sort_order'] not in sort_order_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_order`, must be one of {0}".format(sort_order_allowed_values)
                )

        query_params = {
            "limit": kwargs.get("limit", missing),
            "page": kwargs.get("page", missing),
            "sortBy": kwargs.get("sort_by", missing),
            "sortOrder": kwargs.get("sort_order", missing)
        }
        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                query_params=query_params,
                header_params=header_params,
                response_type="list[SecretBundleVersionSummary]")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                query_params=query_params,
                header_params=header_params,
                response_type="list[SecretBundleVersionSummary]")



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Group(object):
    """
    Represents the current state of a consumer group, including partition reservations and committed offsets.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Group object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param stream_id:
            The value to assign to the stream_id property of this Group.
        :type stream_id: str

        :param group_name:
            The value to assign to the group_name property of this Group.
        :type group_name: str

        :param reservations:
            The value to assign to the reservations property of this Group.
        :type reservations: list[oci.streaming.models.PartitionReservation]

        """
        self.swagger_types = {
            'stream_id': 'str',
            'group_name': 'str',
            'reservations': 'list[PartitionReservation]'
        }

        self.attribute_map = {
            'stream_id': 'streamId',
            'group_name': 'groupName',
            'reservations': 'reservations'
        }

        self._stream_id = None
        self._group_name = None
        self._reservations = None

    @property
    def stream_id(self):
        """
        **[Required]** Gets the stream_id of this Group.
        The streamId for which the group exists.


        :return: The stream_id of this Group.
        :rtype: str
        """
        return self._stream_id

    @stream_id.setter
    def stream_id(self, stream_id):
        """
        Sets the stream_id of this Group.
        The streamId for which the group exists.


        :param stream_id: The stream_id of this Group.
        :type: str
        """
        self._stream_id = stream_id

    @property
    def group_name(self):
        """
        **[Required]** Gets the group_name of this Group.
        The name of the consumer group.


        :return: The group_name of this Group.
        :rtype: str
        """
        return self._group_name

    @group_name.setter
    def group_name(self, group_name):
        """
        Sets the group_name of this Group.
        The name of the consumer group.


        :param group_name: The group_name of this Group.
        :type: str
        """
        self._group_name = group_name

    @property
    def reservations(self):
        """
        Gets the reservations of this Group.
        An array of the partition reservations of a group.


        :return: The reservations of this Group.
        :rtype: list[oci.streaming.models.PartitionReservation]
        """
        return self._reservations

    @reservations.setter
    def reservations(self, reservations):
        """
        Sets the reservations of this Group.
        An array of the partition reservations of a group.


        :param reservations: The reservations of this Group.
        :type: list[oci.streaming.models.PartitionReservation]
        """
        self._reservations = reservations

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ScaledBlockchainPlatformPreview(object):
    """
    Blockchain Platform Instance Description Preview after Scaling.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ScaledBlockchainPlatformPreview object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ScaledBlockchainPlatformPreview.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this ScaledBlockchainPlatformPreview.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ScaledBlockchainPlatformPreview.
        :type compartment_id: str

        :param description:
            The value to assign to the description property of this ScaledBlockchainPlatformPreview.
        :type description: str

        :param compute_shape:
            The value to assign to the compute_shape property of this ScaledBlockchainPlatformPreview.
        :type compute_shape: str

        :param storage_size_in_tbs:
            The value to assign to the storage_size_in_tbs property of this ScaledBlockchainPlatformPreview.
        :type storage_size_in_tbs: float

        :param storage_size_in_tbs_post_scaling:
            The value to assign to the storage_size_in_tbs_post_scaling property of this ScaledBlockchainPlatformPreview.
        :type storage_size_in_tbs_post_scaling: float

        :param component_details:
            The value to assign to the component_details property of this ScaledBlockchainPlatformPreview.
        :type component_details: oci.blockchain.models.BlockchainPlatformComponentDetails

        :param replicas:
            The value to assign to the replicas property of this ScaledBlockchainPlatformPreview.
        :type replicas: oci.blockchain.models.ReplicaDetails

        :param component_details_post_scaling:
            The value to assign to the component_details_post_scaling property of this ScaledBlockchainPlatformPreview.
        :type component_details_post_scaling: oci.blockchain.models.BlockchainPlatformComponentDetails

        :param replicas_post_scaling:
            The value to assign to the replicas_post_scaling property of this ScaledBlockchainPlatformPreview.
        :type replicas_post_scaling: oci.blockchain.models.ReplicaDetails

        :param host_ocpu_utilization_info:
            The value to assign to the host_ocpu_utilization_info property of this ScaledBlockchainPlatformPreview.
        :type host_ocpu_utilization_info: list[oci.blockchain.models.OcpuUtilizationInfo]

        :param host_ocpu_utilization_info_post_scaling:
            The value to assign to the host_ocpu_utilization_info_post_scaling property of this ScaledBlockchainPlatformPreview.
        :type host_ocpu_utilization_info_post_scaling: list[oci.blockchain.models.OcpuUtilizationInfo]

        :param new_vm_count:
            The value to assign to the new_vm_count property of this ScaledBlockchainPlatformPreview.
        :type new_vm_count: int

        :param metering_preview:
            The value to assign to the metering_preview property of this ScaledBlockchainPlatformPreview.
        :type metering_preview: oci.blockchain.models.ScaledPlatformMeteringPreview

        :param scale_payload:
            The value to assign to the scale_payload property of this ScaledBlockchainPlatformPreview.
        :type scale_payload: oci.blockchain.models.ScaleBlockchainPlatformDetails

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'compartment_id': 'str',
            'description': 'str',
            'compute_shape': 'str',
            'storage_size_in_tbs': 'float',
            'storage_size_in_tbs_post_scaling': 'float',
            'component_details': 'BlockchainPlatformComponentDetails',
            'replicas': 'ReplicaDetails',
            'component_details_post_scaling': 'BlockchainPlatformComponentDetails',
            'replicas_post_scaling': 'ReplicaDetails',
            'host_ocpu_utilization_info': 'list[OcpuUtilizationInfo]',
            'host_ocpu_utilization_info_post_scaling': 'list[OcpuUtilizationInfo]',
            'new_vm_count': 'int',
            'metering_preview': 'ScaledPlatformMeteringPreview',
            'scale_payload': 'ScaleBlockchainPlatformDetails'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'description': 'description',
            'compute_shape': 'computeShape',
            'storage_size_in_tbs': 'storageSizeInTBs',
            'storage_size_in_tbs_post_scaling': 'storageSizeInTBsPostScaling',
            'component_details': 'componentDetails',
            'replicas': 'replicas',
            'component_details_post_scaling': 'componentDetailsPostScaling',
            'replicas_post_scaling': 'replicasPostScaling',
            'host_ocpu_utilization_info': 'hostOcpuUtilizationInfo',
            'host_ocpu_utilization_info_post_scaling': 'hostOcpuUtilizationInfoPostScaling',
            'new_vm_count': 'newVmCount',
            'metering_preview': 'meteringPreview',
            'scale_payload': 'scalePayload'
        }

        self._id = None
        self._display_name = None
        self._compartment_id = None
        self._description = None
        self._compute_shape = None
        self._storage_size_in_tbs = None
        self._storage_size_in_tbs_post_scaling = None
        self._component_details = None
        self._replicas = None
        self._component_details_post_scaling = None
        self._replicas_post_scaling = None
        self._host_ocpu_utilization_info = None
        self._host_ocpu_utilization_info_post_scaling = None
        self._new_vm_count = None
        self._metering_preview = None
        self._scale_payload = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ScaledBlockchainPlatformPreview.
        unique identifier that is immutable on creation


        :return: The id of this ScaledBlockchainPlatformPreview.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ScaledBlockchainPlatformPreview.
        unique identifier that is immutable on creation


        :param id: The id of this ScaledBlockchainPlatformPreview.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ScaledBlockchainPlatformPreview.
        Platform Instance Display name, can be renamed


        :return: The display_name of this ScaledBlockchainPlatformPreview.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ScaledBlockchainPlatformPreview.
        Platform Instance Display name, can be renamed


        :param display_name: The display_name of this ScaledBlockchainPlatformPreview.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ScaledBlockchainPlatformPreview.
        Compartment Identifier


        :return: The compartment_id of this ScaledBlockchainPlatformPreview.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ScaledBlockchainPlatformPreview.
        Compartment Identifier


        :param compartment_id: The compartment_id of this ScaledBlockchainPlatformPreview.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def description(self):
        """
        Gets the description of this ScaledBlockchainPlatformPreview.
        Platform Instance Description


        :return: The description of this ScaledBlockchainPlatformPreview.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ScaledBlockchainPlatformPreview.
        Platform Instance Description


        :param description: The description of this ScaledBlockchainPlatformPreview.
        :type: str
        """
        self._description = description

    @property
    def compute_shape(self):
        """
        **[Required]** Gets the compute_shape of this ScaledBlockchainPlatformPreview.
        Compute shape - STANDARD or ENTERPRISE_SMALL or ENTERPRISE_MEDIUM or ENTERPRISE_LARGE or ENTERPRISE_EXTRA_LARGE or ENTERPRISE_CUSTOM


        :return: The compute_shape of this ScaledBlockchainPlatformPreview.
        :rtype: str
        """
        return self._compute_shape

    @compute_shape.setter
    def compute_shape(self, compute_shape):
        """
        Sets the compute_shape of this ScaledBlockchainPlatformPreview.
        Compute shape - STANDARD or ENTERPRISE_SMALL or ENTERPRISE_MEDIUM or ENTERPRISE_LARGE or ENTERPRISE_EXTRA_LARGE or ENTERPRISE_CUSTOM


        :param compute_shape: The compute_shape of this ScaledBlockchainPlatformPreview.
        :type: str
        """
        self._compute_shape = compute_shape

    @property
    def storage_size_in_tbs(self):
        """
        Gets the storage_size_in_tbs of this ScaledBlockchainPlatformPreview.
        Storage size in TBs


        :return: The storage_size_in_tbs of this ScaledBlockchainPlatformPreview.
        :rtype: float
        """
        return self._storage_size_in_tbs

    @storage_size_in_tbs.setter
    def storage_size_in_tbs(self, storage_size_in_tbs):
        """
        Sets the storage_size_in_tbs of this ScaledBlockchainPlatformPreview.
        Storage size in TBs


        :param storage_size_in_tbs: The storage_size_in_tbs of this ScaledBlockchainPlatformPreview.
        :type: float
        """
        self._storage_size_in_tbs = storage_size_in_tbs

    @property
    def storage_size_in_tbs_post_scaling(self):
        """
        Gets the storage_size_in_tbs_post_scaling of this ScaledBlockchainPlatformPreview.
        Storage size in TBs post scaling


        :return: The storage_size_in_tbs_post_scaling of this ScaledBlockchainPlatformPreview.
        :rtype: float
        """
        return self._storage_size_in_tbs_post_scaling

    @storage_size_in_tbs_post_scaling.setter
    def storage_size_in_tbs_post_scaling(self, storage_size_in_tbs_post_scaling):
        """
        Sets the storage_size_in_tbs_post_scaling of this ScaledBlockchainPlatformPreview.
        Storage size in TBs post scaling


        :param storage_size_in_tbs_post_scaling: The storage_size_in_tbs_post_scaling of this ScaledBlockchainPlatformPreview.
        :type: float
        """
        self._storage_size_in_tbs_post_scaling = storage_size_in_tbs_post_scaling

    @property
    def component_details(self):
        """
        Gets the component_details of this ScaledBlockchainPlatformPreview.

        :return: The component_details of this ScaledBlockchainPlatformPreview.
        :rtype: oci.blockchain.models.BlockchainPlatformComponentDetails
        """
        return self._component_details

    @component_details.setter
    def component_details(self, component_details):
        """
        Sets the component_details of this ScaledBlockchainPlatformPreview.

        :param component_details: The component_details of this ScaledBlockchainPlatformPreview.
        :type: oci.blockchain.models.BlockchainPlatformComponentDetails
        """
        self._component_details = component_details

    @property
    def replicas(self):
        """
        Gets the replicas of this ScaledBlockchainPlatformPreview.

        :return: The replicas of this ScaledBlockchainPlatformPreview.
        :rtype: oci.blockchain.models.ReplicaDetails
        """
        return self._replicas

    @replicas.setter
    def replicas(self, replicas):
        """
        Sets the replicas of this ScaledBlockchainPlatformPreview.

        :param replicas: The replicas of this ScaledBlockchainPlatformPreview.
        :type: oci.blockchain.models.ReplicaDetails
        """
        self._replicas = replicas

    @property
    def component_details_post_scaling(self):
        """
        Gets the component_details_post_scaling of this ScaledBlockchainPlatformPreview.

        :return: The component_details_post_scaling of this ScaledBlockchainPlatformPreview.
        :rtype: oci.blockchain.models.BlockchainPlatformComponentDetails
        """
        return self._component_details_post_scaling

    @component_details_post_scaling.setter
    def component_details_post_scaling(self, component_details_post_scaling):
        """
        Sets the component_details_post_scaling of this ScaledBlockchainPlatformPreview.

        :param component_details_post_scaling: The component_details_post_scaling of this ScaledBlockchainPlatformPreview.
        :type: oci.blockchain.models.BlockchainPlatformComponentDetails
        """
        self._component_details_post_scaling = component_details_post_scaling

    @property
    def replicas_post_scaling(self):
        """
        Gets the replicas_post_scaling of this ScaledBlockchainPlatformPreview.

        :return: The replicas_post_scaling of this ScaledBlockchainPlatformPreview.
        :rtype: oci.blockchain.models.ReplicaDetails
        """
        return self._replicas_post_scaling

    @replicas_post_scaling.setter
    def replicas_post_scaling(self, replicas_post_scaling):
        """
        Sets the replicas_post_scaling of this ScaledBlockchainPlatformPreview.

        :param replicas_post_scaling: The replicas_post_scaling of this ScaledBlockchainPlatformPreview.
        :type: oci.blockchain.models.ReplicaDetails
        """
        self._replicas_post_scaling = replicas_post_scaling

    @property
    def host_ocpu_utilization_info(self):
        """
        Gets the host_ocpu_utilization_info of this ScaledBlockchainPlatformPreview.
        List of OcpuUtilization for all hosts


        :return: The host_ocpu_utilization_info of this ScaledBlockchainPlatformPreview.
        :rtype: list[oci.blockchain.models.OcpuUtilizationInfo]
        """
        return self._host_ocpu_utilization_info

    @host_ocpu_utilization_info.setter
    def host_ocpu_utilization_info(self, host_ocpu_utilization_info):
        """
        Sets the host_ocpu_utilization_info of this ScaledBlockchainPlatformPreview.
        List of OcpuUtilization for all hosts


        :param host_ocpu_utilization_info: The host_ocpu_utilization_info of this ScaledBlockchainPlatformPreview.
        :type: list[oci.blockchain.models.OcpuUtilizationInfo]
        """
        self._host_ocpu_utilization_info = host_ocpu_utilization_info

    @property
    def host_ocpu_utilization_info_post_scaling(self):
        """
        Gets the host_ocpu_utilization_info_post_scaling of this ScaledBlockchainPlatformPreview.
        List of OcpuUtilization for all hosts after scaling


        :return: The host_ocpu_utilization_info_post_scaling of this ScaledBlockchainPlatformPreview.
        :rtype: list[oci.blockchain.models.OcpuUtilizationInfo]
        """
        return self._host_ocpu_utilization_info_post_scaling

    @host_ocpu_utilization_info_post_scaling.setter
    def host_ocpu_utilization_info_post_scaling(self, host_ocpu_utilization_info_post_scaling):
        """
        Sets the host_ocpu_utilization_info_post_scaling of this ScaledBlockchainPlatformPreview.
        List of OcpuUtilization for all hosts after scaling


        :param host_ocpu_utilization_info_post_scaling: The host_ocpu_utilization_info_post_scaling of this ScaledBlockchainPlatformPreview.
        :type: list[oci.blockchain.models.OcpuUtilizationInfo]
        """
        self._host_ocpu_utilization_info_post_scaling = host_ocpu_utilization_info_post_scaling

    @property
    def new_vm_count(self):
        """
        Gets the new_vm_count of this ScaledBlockchainPlatformPreview.
        Number of new VMs that would be created


        :return: The new_vm_count of this ScaledBlockchainPlatformPreview.
        :rtype: int
        """
        return self._new_vm_count

    @new_vm_count.setter
    def new_vm_count(self, new_vm_count):
        """
        Sets the new_vm_count of this ScaledBlockchainPlatformPreview.
        Number of new VMs that would be created


        :param new_vm_count: The new_vm_count of this ScaledBlockchainPlatformPreview.
        :type: int
        """
        self._new_vm_count = new_vm_count

    @property
    def metering_preview(self):
        """
        Gets the metering_preview of this ScaledBlockchainPlatformPreview.

        :return: The metering_preview of this ScaledBlockchainPlatformPreview.
        :rtype: oci.blockchain.models.ScaledPlatformMeteringPreview
        """
        return self._metering_preview

    @metering_preview.setter
    def metering_preview(self, metering_preview):
        """
        Sets the metering_preview of this ScaledBlockchainPlatformPreview.

        :param metering_preview: The metering_preview of this ScaledBlockchainPlatformPreview.
        :type: oci.blockchain.models.ScaledPlatformMeteringPreview
        """
        self._metering_preview = metering_preview

    @property
    def scale_payload(self):
        """
        Gets the scale_payload of this ScaledBlockchainPlatformPreview.

        :return: The scale_payload of this ScaledBlockchainPlatformPreview.
        :rtype: oci.blockchain.models.ScaleBlockchainPlatformDetails
        """
        return self._scale_payload

    @scale_payload.setter
    def scale_payload(self, scale_payload):
        """
        Sets the scale_payload of this ScaledBlockchainPlatformPreview.

        :param scale_payload: The scale_payload of this ScaledBlockchainPlatformPreview.
        :type: oci.blockchain.models.ScaleBlockchainPlatformDetails
        """
        self._scale_payload = scale_payload

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
